@@ -28,18 +28,16 @@ let encoder wav =
   let channels = wav.channels in
   let sample_rate = Lazy.force wav.samplerate in
   let sample_size = wav.samplesize in
-  let ratio =
-    (float sample_rate) /. (float (Lazy.force Frame.audio_rate))
-  in
+  let ratio = float sample_rate /. float (Lazy.force Frame.audio_rate) in
   let converter = Audio_converter.Samplerate.create channels in
-  let len = 
+  let len =
     match wav.duration with
       | None -> None
-      | Some d -> 
-          Some (
-            int_of_float (d *. (float channels) *. 
-                               (float sample_rate) *.
-                               (float sample_size) /. 8.))
+      | Some d ->
+          Some
+            (int_of_float
+               ( d *. float channels *. float sample_rate *. float sample_size
+               /. 8. ))
   in
   let header =
     Wav_aiff.wav_header ?len ~channels ~sample_rate ~sample_size ()
@@ -50,15 +48,13 @@ let encoder wav =
     let b = AFrame.content_of_type ~channels frame start in
     let len = Frame.audio_of_master len in
     (* Resample if needed. *)
-    let b,start,len =
-      if ratio = 1. then
-        b,start,len
-      else
+    let b, start, len =
+      if ratio = 1. then (b, start, len)
+      else (
         let b =
-          Audio_converter.Samplerate.resample
-                 converter ratio b start len
+          Audio_converter.Samplerate.resample converter ratio b start len
         in
-        b,0,Array.length b.(0)
+        (b, 0, Array.length b.(0)) )
     in
     let s = Bytes.create (sample_size / 8 * len * channels) in
     let of_audio =
@@ -72,21 +68,19 @@ let encoder wav =
     of_audio b start s 0 len;
     let s = Bytes.unsafe_to_string s in
     if !need_header then begin
-      need_header := false ;
+      need_header := false;
       header ^ s
-    end else
-      s
+    end
+    else s
   in
-    {
-     Encoder.
-      insert_metadata = (fun _ -> ()) ;
-      encode = encode ;
-      header = Some header ;
-      stop = (fun () -> "")
-    }
+  {
+    Encoder.insert_metadata = (fun _ -> ());
+    encode;
+    header = Some header;
+    stop = (fun () -> "");
+  }
 
 let () =
-  Encoder.plug#register "WAV"
-    (function
-       | Encoder.WAV w -> Some (fun _ _ -> encoder w)
-       | _ -> None)
+  Encoder.plug#register "WAV" (function
+    | Encoder.WAV w -> Some (fun _ _ -> encoder w)
+    | _ -> None)
